.. wiggle documentation master file, created by
   sphinx-quickstart on Wed Jun 11 13:12:23 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

wiggle documentation
====================

Welcome to the documentation for ``wiggle``,  a tool for fast unbiased angular power spectrum estimation of spin-0 and spin-2 fields on the sphere, most commonly encountered in the context of cosmological data analysis.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   reference
